@@ -9,7 +9,6 @@
 #include "functions.h"
 #include "functions_p.h"
 
-#include "akonadicollectionsearch.h"
 #include "displaycalendar.h"
 #include "kalarmapp.h"
 #include "kamail.h"
@@ -23,12 +22,13 @@
 #include "resources/resources.h"
 #include "resources/eventmodel.h"
 #include "lib/autoqpointer.h"
+#include "lib/dragdrop.h"
 #include "lib/filedialog.h"
 #include "lib/messagebox.h"
 #include "lib/shellprocess.h"
 #include "kalarmcalendar/identities.h"
+#include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
-#include "config-kalarm.h"
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/ICalFormat>
@@ -46,13 +46,8 @@ using namespace KCalendarCore;
 #include <KLocalizedString>
 
 #if ENABLE_WAKE_FROM_SUSPEND
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/ActionReply>
 #include <KAuth/ExecuteJob>
-#else
-#include <KAuth>
-#endif
 #endif
 #include <KStandardShortcut>
 #include <KFileItem>
@@ -67,7 +62,8 @@ using namespace KCalendarCore;
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QTimer>
-#include <qglobal.h>
+#include <QtGlobal>
+#include <QMimeData>
 #include <QStandardPaths>
 #include <QPushButton>
 #include <QTemporaryFile>
@@ -120,15 +116,11 @@ struct UpdateStatusData
     }
 };
 
-const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
-//const QLatin1String KMAIL_DBUS_IFACE("org.kde.kmail.kmail");
-//const QLatin1String KMAIL_DBUS_WINDOW_PATH("/kmail/kmail_mainwindow_1");
 const QLatin1String KORG_DBUS_SERVICE("org.kde.korganizer");
 const QLatin1String KORG_DBUS_IFACE("org.kde.korganizer.Korganizer");
 // D-Bus object path of KOrganizer's notification interface
 #define       KORG_DBUS_PATH            "/Korganizer"
 #define       KORG_DBUS_LOAD_PATH       "/korganizer_PimApplication"
-//const QLatin1String KORG_DBUS_WINDOW_PATH("/korganizer/MainWindow_1");
 const QLatin1String KORG_MIME_TYPE("application/x-vnd.akonadi.calendar.event");
 const QLatin1String KORGANIZER_UID("korg-");
 
@@ -1669,28 +1661,6 @@ void refreshAlarmsIfQueued()
     }
 }
 
-/******************************************************************************
-* Start KMail if it isn't already running, optionally minimised.
-* Reply = reason for failure to run KMail
-*       = null string if success.
-*/
-QString runKMail()
-{
-    const QDBusReply<bool> reply = QDBusConnection::sessionBus().interface()->isServiceRegistered(KMAIL_DBUS_SERVICE);
-    if (!reply.isValid()  ||  !reply.value())
-    {
-        // Program is not already running, so start it
-        const QDBusReply<void> startReply = QDBusConnection::sessionBus().interface()->startService(KMAIL_DBUS_SERVICE);
-        if (!startReply.isValid())
-        {
-            const QString errmsg = startReply.error().message();
-            qCCritical(KALARM_LOG) << "Couldn't start KMail (" << errmsg << ")";
-            return xi18nc("@info", "Unable to start <application>KMail</application><nl/>(<message>%1</message>)", errmsg);
-        }
-    }
-    return {};
-}
-
 /******************************************************************************
 * The "Don't show again" option for error messages is personal to the user on a
 * particular computer. For example, he may want to inhibit error messages only
@@ -1887,6 +1857,35 @@ bool convertTimeString(const QByteArray& timeString, KADateTime& dateTime, const
     return dateTime.isValid();
 }
 
+/******************************************************************************
+* Extract dragged and dropped Akonadi RFC822 message data.
+*/
+bool dropAkonadiEmail(const QMimeData* data, QUrl& url, AlarmText& alarmText)
+{
+    alarmText.clear();
+    const QList<QUrl> urls = data->urls();
+    if (urls.isEmpty())
+        url = QUrl();
+    else
+    {
+        url  = urls.at(0);
+        AkonadiPlugin* akonadiPlugin = Preferences::akonadiPlugin();
+        if (akonadiPlugin)
+        {
+            KAEvent::EmailId emailId;
+            KMime::Message::Ptr message = akonadiPlugin->fetchAkonadiEmail(url, emailId);
+            if (message)
+            {
+                // It's an email held in Akonadi
+                if (message->hasContent())
+                    alarmText = DragDrop::kMimeEmailToAlarmText(*message, emailId);
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
 /******************************************************************************
 * Convert a time zone specifier string and apply it to a given date and/or time.
 * The time zone specifier is a system time zone name, e.g. "Europe/London" or
@@ -2089,8 +2088,12 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
 */
 KAlarm::UpdateResult deleteFromKOrganizer(const QString& eventID)
 {
+    AkonadiPlugin* akonadiPlugin = Preferences::akonadiPlugin();
+    if (!akonadiPlugin)
+        return KAlarm::UpdateResult(KAlarm::UPDATE_KORG_ERR);
+
     const QString newID = uidKOrganizer(eventID);
-    new AkonadiCollectionSearch(KORG_MIME_TYPE, QString(), newID, true);  // this auto-deletes when complete
+    akonadiPlugin->deleteEvent(KORG_MIME_TYPE, QString(), newID);
     // Ignore errors
     return KAlarm::UpdateResult(KAlarm::UPDATE_OK);
 }
